summaryrefslogtreecommitdiffstats
path: root/kalzium/src/kalzium.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/kalzium.cpp')
-rw-r--r--kalzium/src/kalzium.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kalzium/src/kalzium.cpp b/kalzium/src/kalzium.cpp
index 011aecb6..2046825b 100644
--- a/kalzium/src/kalzium.cpp
+++ b/kalzium/src/kalzium.cpp
@@ -50,7 +50,7 @@
#include <kdialogbase.h>
#include <knuminput.h>
-#include <kdeeduglossary.h>
+#include <tdeeduglossary.h>
#define PerodicTableView_MARGIN 5
#define IDS_ELEMENTINFO 7
@@ -84,8 +84,8 @@ Kalzium::Kalzium()
setupSidebars();
setupActions();
- // adding the libkdeedu catalog
- KGlobal::locale()->insertCatalogue( "libkdeedu" );
+ // adding the libtdeedu catalog
+ KGlobal::locale()->insertCatalogue( "libtdeedu" );
// creating the glossary dialog and loading the glossaries we have
m_glossarydlg = new GlossaryDialog( true, this, "glossary" );